@@ -23,7 +23,7 @@ sub valid_values {
         # '[ 1-9 ][ 0-9 ]*'
         keep       => [ 1, 2, 100, 999999, undef ],
         ll         => [ 1, 2, 100, 999999, undef ],
-        limit      => [ 1, 2, 100, 999999, undef ],
+#        limit      => [ 1, 2, 100, 999999, undef ],
         max_height => [ 1, 2, 100, 999999, undef ],
         max_width  => [ 1, 2, 100, 999999, undef ],
 
@@ -48,20 +48,22 @@ sub valid_values {
 sub mixed_options_1 {
     return {
         beep  => 0, clear_screen => undef, hide_cursor => 1, index => 0, justify => 0, layout => 0, mouse => 0,
-        order => 1, page => 0, keep => 1, ll => 1, limit => 9, max_height => 19, max_width => 19, default => 9,
+        order => 1, page => 0, keep => 1, ll => 1, max_height => 19, max_width => 19, default => 9,
         pad => 3, pad_one_row => 2, empty => '', prompt => '', undef => '', lf => [ 1 ], no_spacebar => [ 0 ]
     };
 }
 
+# limit => 9,
+
 sub mixed_options_2 {
     return {
         no_spacebar => [ 11, 0, 8 ], lf => [ 1, 1 ], undef => '', prompt => 'prompt_line', empty => '', pad_one_row => 2, pad => 3,
-        default => 9, max_width => 19, max_height => 119,  limit => 999999, ll => 15, keep => 1, page => 1, order => 1,
+        default => 9, max_width => 19, max_height => 119, ll => 15, keep => 1, page => 1, order => 1,
         mouse => 0, layout => 3, justify => 0, index => 0, hide_cursor => 1,  clear_screen => undef, beep  => 0
     };
 }
 
-
+# limit => 999999,
 
 ##################################################################################################
 
@@ -79,7 +81,7 @@ sub invalid_values {
         page         => [ grep { ! /^[ 0 1 ]\z/x }         @invalid ],
         keep         => [ grep { ! /^[ 1-9 ][ 0-9 ]*\z/x } @invalid ],
         ll           => [ grep { ! /^[ 1-9 ][ 0-9 ]*\z/x } @invalid ],
-        limit        => [ grep { ! /^[ 1-9 ][ 0-9 ]*\z/x } @invalid ],
+#        limit        => [ grep { ! /^[ 1-9 ][ 0-9 ]*\z/x } @invalid ],
         max_height   => [ grep { ! /^[ 1-9 ][ 0-9 ]*\z/x } @invalid ],
         max_width    => [ grep { ! /^[ 1-9 ][ 0-9 ]*\z/x } @invalid ],
         default      => [ grep { ! /^[ 0-9 ]+\z/x }        @invalid ],
@@ -102,20 +104,22 @@ sub invalid_values {
 sub mixed_invalid_1 {
     return {
         beep  => -1, clear_screen => 2, hide_cursor => 3, index => 4, justify => '@', layout => 5, mouse => {},
-        order => 1, page => 0, keep => -1, ll => -1, limit => 0, max_height => 0, max_width => 0, default => [],
+        order => 1, page => 0, keep => -1, ll => -1, max_height => 0, max_width => 0, default => [],
         pad => 'a', pad_one_row => 'b', empty => [], prompt => {}, undef => [], lf => 4, no_spacebar => 4
     };
 }
 
+# limit => 0,
+
 sub mixed_invalid_2 {
     return {
         no_spacebar => 'a', lf => 'b', undef => [], prompt => {}, empty => {}, pad_one_row => 'c', pad => 'd',
-        default => 'e', max_width => -1, max_height => -2,  limit => -3, ll => -4, keep => -5, page => -6, order => -7,
+        default => 'e', max_width => -1, max_height => -2, ll => -4, keep => -5, page => -6, order => -7,
         mouse => 'k', layout => 'e', justify => [], index => {}, hide_cursor => -1,  clear_screen => [], beep  => 10
     };
 }
 
-
+#  limit => -3,
 
 
 
